==> haskell-casa-types-0.0.2-425-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 casa-types
version:              0.0.2
visibility:           public
id:                   casa-types-0.0.2-EbJPco1cJEU6zrGftbhLhr
key:                  casa-types-0.0.2-EbJPco1cJEU6zrGftbhLhr
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Types for Casa
description:          Types for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  131876522b351c97a2f9be09b9ce0f54
exposed:              True
exposed-modules:      Casa.Types
hidden-modules:       Paths_casa_types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/casa-types-0.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/casa-types-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-types
hs-libraries:         HScasa-types-0.0.2-EbJPco1cJEU6zrGftbhLhr
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    attoparsec-0.14.4-l6gpYVAuXa4krkAJlMwbn base-4.16.4.0
    base16-bytestring-1.0.2.0-KWjk12Kc0JO2Mp5RJvDvOx
    bytestring-0.11.4.0 hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc
    path-pieces-0.2.1-E15XfVOwfTfIr2VliI4YGA
    persistent-2.14.5.1-9xnFRv8rkde2AoeFkZgfdg text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-casa-types-0.0.2-426-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 casa-types
version:              0.0.2
visibility:           public
id:                   casa-types-0.0.2-InSlJRSe5IULJyMuLFU7M3
key:                  casa-types-0.0.2-InSlJRSe5IULJyMuLFU7M3
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Types for Casa
description:          Types for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  be469826fcc4b3f9c294b16b4fd91e36
exposed:              True
exposed-modules:      Casa.Types
hidden-modules:       Paths_casa_types
import-dirs:          /usr/lib/ghc-9.2.8/site-local/casa-types-0.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/casa-types-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-types
hs-libraries:         HScasa-types-0.0.2-InSlJRSe5IULJyMuLFU7M3
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8
    attoparsec-0.14.4-HEPxPDNq5mJKRZZEtIXOMd base-4.16.4.0
    base16-bytestring-1.0.2.0-9AKEfJpeJHOK2mzYhoV7G4
    bytestring-0.11.4.0 hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    path-pieces-0.2.1-E15XfVOwfTfIr2VliI4YGA
    persistent-2.14.5.1-Lra5mco7v3oDrLn8V2e89 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
